#[derive(Shapely)]Expand description
Derive the [shapely_core::Shapely] trait for structs, tuple structs, and enums.
This uses unsynn, so it’s light, but it will choke on some Rust syntax because… there’s a lot of Rust syntax.
#[derive(Shapely)]Derive the [shapely_core::Shapely] trait for structs, tuple structs, and enums.
This uses unsynn, so it’s light, but it will choke on some Rust syntax because… there’s a lot of Rust syntax.